@@ -190,7 +190,7 @@ class ImgCompounder:
             self.camera_border_stroke_width = 46
             self.camera_border_text_list = [
                 {
-                    'left': 180,
+                    'left': 120,
                     'top': 500,
                     'angle': 0,
                     'flip': 1
@@ -199,35 +199,35 @@ class ImgCompounder:
                     'left': 500,
                     'top': 500,
                     'angle': 45,
-                    'flip': 1
+                    'flip': 0
                 },
                 {
                     'left': 500,
-                    'top': 180,
+                    'top': 120,
                     'angle': 90,
-                    'flip': 1
+                    'flip': 0
                 },
                 {
                     'left': 500,
                     'top': 500,
                     'angle': 135,
-                    'flip': 1
+                    'flip': 0
                 },
                 {
-                    'left': 180,
+                    'left': 120,
                     'top': 500,
                     'angle': 180,
-                    'flip': 1
+                    'flip': 0
                 },
                 {
                     'left': 400,
                     'top': 500,
                     'angle': 225,
-                    'flip': 1
+                    'flip': 0
                 },
                 {
                     'left': 400,
-                    'top': 180,
+                    'top': 120,
                     'angle': 270,
                     'flip': 1
                 },
@@ -235,12 +235,12 @@ class ImgCompounder:
                     'left': 400,
                     'top': 500,
                     'angle': 315,
-                    'flip': 1
+                    'flip': 0
                 },
             ]
             self.camera_border_logo_list = [
                 {
-                    'left': 250,
+                    'left': 280,
                     'top': 0,
                     'angle': 0
                 },
@@ -251,7 +251,7 @@ class ImgCompounder:
                 },
                 {
                     'left': 500,
-                    'top': 250,
+                    'top': 280,
                     'angle': 90
                 },
                 {
@@ -260,7 +260,7 @@ class ImgCompounder:
                     'angle': 135
                 },
                 {
-                    'left': 250,
+                    'left': 280,
                     'top': 800,
                     'angle': 180
                 },
@@ -271,7 +271,7 @@ class ImgCompounder:
                 },
                 {
                     'left': 500,
-                    'top': 250,
+                    'top': 280,
                     'angle': 270
                 },
                 {
@@ -735,7 +735,7 @@ class ImgCompounder:
                             top = 0 + self.camera_border_top
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2
+                                top = self.camera_border_top + (self.camera_border_stroke_width - text_height) / 2 + 5
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 45:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -755,7 +755,8 @@ class ImgCompounder:
                                                      text_color=text_dict[text],
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_width - self.camera_border_stroke_width + \
-                                   (self.camera_border_stroke_width - text_height) / 2 + 3 + self.camera_border_left
+                                   (self.camera_border_stroke_width - text_height) / 2 + \
+                                   self.camera_border_left + 5
                             top = camera_border_text['top'] + self.camera_border_top
                             text_image = text_image.transpose(Image.ROTATE_270)
                             if camera_border_text['flip'] == 1:
@@ -780,7 +781,7 @@ class ImgCompounder:
                                                      border_stroke_width=self.camera_border_stroke_width)
                             left = self.camera_border_left + camera_border_text['left']
                             top = self.camera_border_top + self.camera_border_height - self.camera_border_stroke_width + \
-                                  (self.camera_border_stroke_width - text_height) / 2
+                                  (self.camera_border_stroke_width - text_height) / 2 + 5
                             text_image = text_image.transpose(Image.ROTATE_180)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
@@ -808,7 +809,7 @@ class ImgCompounder:
                             text_image = text_image.transpose(Image.ROTATE_90)
                             if camera_border_text['flip'] == 1:
                                 text_image = text_image.rotate(180)
-                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2
+                                left = self.camera_border_left + (self.camera_border_stroke_width - text_height) / 2 + 5
                             compound_img.paste(text_image, (int(left), int(top)), text_image)
                         if camera_border_text['angle'] == 315:
                             arcs_text_img = self.__draw_arcs_text_img(text=text,
@@ -1006,6 +1007,10 @@ class ImgCompounder:
         text_height = font_size[1]
         text_image = Image.new(size=(text_width, text_height), mode='RGBA')
         text_draw = ImageDraw.Draw(text_image)
+
+        bbox = text_draw.textbbox((0, 0), text, font=font)
+        text_height = bbox[3] - bbox[0]
+
         text_draw.text((0, 0), text, font=font, spacing=0, fill='#' + text_color, align='left', direction='ltr')
         return text_image, text_width, text_height
 
